diff --git a/NEWS b/NEWS
index d9d09cb5440cc56c34973c79e65b2e075f6c3bc9..c9bcaf3d1671b983325360568ebb28fda64ca048 100644
--- a/NEWS
+++ b/NEWS
@@ -22,6 +22,7 @@ documents those changes that are of interest to users and admins.
     erroneously on a bluegene system.
  -- sacct - fix --name and --partition options when using
     accounting_storage/filetxt.
+ -- squeue - Remove extra whitespace of default printout.
 
 * Changes in Slurm 2.6.0
 ========================
diff --git a/src/common/slurmdb_defs.c b/src/common/slurmdb_defs.c
index 1a97df4c673d1c6612dfbc419c1919c71ee71322..238456bbe53317871b49925b63886b49509076b6 100644
--- a/src/common/slurmdb_defs.c
+++ b/src/common/slurmdb_defs.c
@@ -115,7 +115,7 @@ static void _free_cluster_cond_members(slurmdb_cluster_cond_t *cluster_cond)
 /*
  * Comparator used for sorting immediate childern of acct_hierarchical_recs
  *
- * returns: -1: assoc_a > assoc_b   0: assoc_a == assoc_b   1: assoc_a < assoc_b
+ * returns: -1 assoc_a < assoc_b   0: assoc_a == assoc_b   1: assoc_a > assoc_b
  *
  */
 
@@ -155,7 +155,7 @@ static int _sort_children_list(void *v1, void *v2)
 /*
  * Comparator used for sorting immediate childern of acct_hierarchical_recs
  *
- * returns: -1: assoc_a > assoc_b   0: assoc_a == assoc_b   1: assoc_a < assoc_b
+ * returns: -1 assoc_a < assoc_b   0: assoc_a == assoc_b   1: assoc_a > assoc_b
  *
  */
 
diff --git a/src/squeue/opts.c b/src/squeue/opts.c
index 6b163ce411f698a68313e1fded485839250a5f81..bb31fea362efaecb9cf4a03b25b9c2dfa7d62b58 100644
--- a/src/squeue/opts.c
+++ b/src/squeue/opts.c
@@ -381,7 +381,7 @@ parse_command_line( int argc, char* argv[] )
 	if ( params.start_flag && !params.step_flag ) {
 		/* Set more defaults */
 		if (params.format == NULL)
-			params.format = xstrdup("%.7i %.9P %.8j %.8u  %.2t  %.19S %.6D %R");
+			params.format = xstrdup("%.7i %.9P %.8j %.8u %.2t %.19S %.6D %R");
 		if (params.sort == NULL)
 			params.sort = xstrdup("S");
 		if (params.states == NULL) {
diff --git a/src/squeue/squeue.c b/src/squeue/squeue.c
index 54ebc5f15fc0221a1d6e9a9824bc3839fb8258f0..f8c73a87913ef7ac312dc4f79ab1a11d5b413271 100644
--- a/src/squeue/squeue.c
+++ b/src/squeue/squeue.c
@@ -230,7 +230,7 @@ _print_job ( bool clear_old )
 				"%.18i %.9P %.8j %.8u %.8T %.10M %.9l %.6D %R");
 		} else {
 			xstrcat(params.format,
-				"%.18i %.9P %.8j %.8u  %.2t %.10M %.6D %R");
+				"%.18i %.9P %.8j %.8u %.2t %.10M %.6D %R");
 		}
 	}
 	if (params.format_list == NULL)
diff --git a/testsuite/expect/test24.1.prog.c b/testsuite/expect/test24.1.prog.c
index 8bd2a4b484f1faff43382e0fbd5779a7e41db62e..9de4877a9e862b8d406c2a09cf7d8293170458ad 100644
--- a/testsuite/expect/test24.1.prog.c
+++ b/testsuite/expect/test24.1.prog.c
@@ -95,11 +95,11 @@ int _setup_assoc_list(void)
 	update.objects = list_create(slurmdb_destroy_association_rec);
 
 	/* Just so we don't have to worry about lft's and rgt's we
 	 * will just push these on in order.
 	 * Note: the commented out lfts and rgts as of 10-29-10 are
-	 * correct.  We do a push instead of append so they go on
+	 * correct.  By doing an append they go on
 	 * sorted in hierarchy order.  The sort that happens inside
-	 * the internal slurm code will sort alpha automatically, (We
+	 * the internal slurm code will sort alpha automatically, (You can
 	 * test this by putting AccountF before AccountE.
 	 */
 
@@ -111,7 +111,7 @@ int _setup_assoc_list(void)
 	/* assoc->lft = 1; */
 	/* assoc->rgt = 28; */
 	assoc->acct = xstrdup("root");
-	list_push(update.objects, assoc);
+	list_append(update.objects, assoc);
 
 	/* sub of root id 1 */
 	assoc = xmalloc(sizeof(slurmdb_association_rec_t));
@@ -122,7 +122,7 @@ int _setup_assoc_list(void)
 	/* assoc->lft = 2; */
 	/* assoc->rgt = 13; */
 	assoc->acct = xstrdup("AccountA");
-	list_push(update.objects, assoc);
+	list_append(update.objects, assoc);
 
 	/* sub of AccountA id 2 */
 	assoc = xmalloc(sizeof(slurmdb_association_rec_t));
@@ -133,7 +133,7 @@ int _setup_assoc_list(void)
 	assoc->parent_id = 2;
 	assoc->shares_raw = 30;
 	assoc->acct = xstrdup("AccountB");
-	list_push(update.objects, assoc);
+	list_append(update.objects, assoc);
 
 	/* sub of AccountB id 21 */
 	assoc = xmalloc(sizeof(slurmdb_association_rec_t));
@@ -146,7 +146,7 @@ int _setup_assoc_list(void)
 	assoc->usage->usage_raw = 20;
 	assoc->acct = xstrdup("AccountB");
 	assoc->user = xstrdup("User1");
-	list_push(update.objects, assoc);
+	list_append(update.objects, assoc);
 
 	/* sub of AccountA id 2 */
 	assoc = xmalloc(sizeof(slurmdb_association_rec_t));
@@ -157,7 +157,7 @@ int _setup_assoc_list(void)
 	assoc->parent_id = 2;
 	assoc->shares_raw = 10;
 	assoc->acct = xstrdup("AccountC");
-	list_push(update.objects, assoc);
+	list_append(update.objects, assoc);
 
 	/* sub of AccountC id 22 */
 	assoc = xmalloc(sizeof(slurmdb_association_rec_t));
@@ -170,7 +170,7 @@ int _setup_assoc_list(void)
 	assoc->usage->usage_raw = 25;
 	assoc->acct = xstrdup("AccountC");
 	assoc->user = xstrdup("User2");
-	list_push(update.objects, assoc);
+	list_append(update.objects, assoc);
 
 	assoc = xmalloc(sizeof(slurmdb_association_rec_t));
 	assoc->usage = create_assoc_mgr_association_usage();
@@ -182,7 +182,7 @@ int _setup_assoc_list(void)
 	assoc->usage->usage_raw = 0;
 	assoc->acct = xstrdup("AccountC");
 	assoc->user = xstrdup("User3");
-	list_push(update.objects, assoc);
+	list_append(update.objects, assoc);
 
 	/* sub of root id 1 */
 	assoc = xmalloc(sizeof(slurmdb_association_rec_t));
@@ -193,7 +193,7 @@ int _setup_assoc_list(void)
 	assoc->parent_id = 1;
 	assoc->shares_raw = 60;
 	assoc->acct = xstrdup("AccountD");
-	list_push(update.objects, assoc);
+	list_append(update.objects, assoc);
 
 	/* sub of AccountD id 3 */
 	assoc = xmalloc(sizeof(slurmdb_association_rec_t));
@@ -204,7 +204,7 @@ int _setup_assoc_list(void)
 	assoc->parent_id = 3;
 	assoc->shares_raw = 25;
 	assoc->acct = xstrdup("AccountE");
-	list_push(update.objects, assoc);
+	list_append(update.objects, assoc);
 
 	/* sub of AccountE id 31 */
 	assoc = xmalloc(sizeof(slurmdb_association_rec_t));
@@ -217,7 +217,7 @@ int _setup_assoc_list(void)
 	assoc->usage->usage_raw = 25;
 	assoc->acct = xstrdup("AccountE");
 	assoc->user = xstrdup("User4");
-	list_push(update.objects, assoc);
+	list_append(update.objects, assoc);
 
 	/* sub of AccountD id 3 */
 	assoc = xmalloc(sizeof(slurmdb_association_rec_t));
@@ -228,7 +228,7 @@ int _setup_assoc_list(void)
 	assoc->parent_id = 3;
 	assoc->shares_raw = 35;
 	assoc->acct = xstrdup("AccountF");
-	list_push(update.objects, assoc);
+	list_append(update.objects, assoc);
 
 	/* sub of AccountF id 32 */
 	assoc = xmalloc(sizeof(slurmdb_association_rec_t));
@@ -241,7 +241,7 @@ int _setup_assoc_list(void)
 	assoc->usage->usage_raw = 0;
 	assoc->acct = xstrdup("AccountF");
 	assoc->user = xstrdup("User5");
-	list_push(update.objects, assoc);
+	list_append(update.objects, assoc);
 
 	/* sub of root id 1 */
 	assoc = xmalloc(sizeof(slurmdb_association_rec_t));
@@ -252,7 +252,7 @@ int _setup_assoc_list(void)
 	assoc->parent_id = 1;
 	assoc->shares_raw = 0;
 	assoc->acct = xstrdup("AccountG");
-	list_push(update.objects, assoc);
+	list_append(update.objects, assoc);
 
 	/* sub of AccountG id 4 */
 	assoc = xmalloc(sizeof(slurmdb_association_rec_t));
@@ -265,7 +265,7 @@ int _setup_assoc_list(void)
 	assoc->usage->usage_raw = 30;
 	assoc->acct = xstrdup("AccountG");
 	assoc->user = xstrdup("User6");
-	list_push(update.objects, assoc);
+	list_append(update.objects, assoc);
 
 	if (assoc_mgr_update_assocs(&update))
 		error("assoc_mgr_update_assocs: %m");
@@ -95,11 +95,11 @@ int _setup_assoc_list(void)
 
 	/* Just so we don't have to worry about lft's and rgt's we
-	 * will just push these on in order.
+	 * will just append these on in order.
 	 * Note: the commented out lfts and rgts as of 10-29-10 are